@@ -21,12 +21,12 @@ class CedictParser:
         self.lines = lines or []
         self.lines_count = lines_count
         
-        if not file_path and os.path.isfile('../data/dump.p'):
-            self.lines = pickle.load( open( "../data/dump.p", "rb" ) )
+        if not file_path and os.path.isfile('data/dump.dat'):
+            self.lines = pickle.load( open( "data/dump.dat", "rb" ) )
         elif file_path:
             self.read_file(file_path)
         else:
-            self.read_file(file_path="../data/cedict_ts.u8")
+            self.read_file(file_path="data/cedict_ts.u8")
 
     def read_file(self, file_path):
         """Import the cedict file sanitizing each entry"""
@@ -40,7 +40,7 @@ class CedictParser:
                 logging.info("Loaded %s lines of the dictionary", self.lines_count)
             self.lines = file_handler.readlines()
             self._sanitize()
-            pickle.dump( self.lines, open( "data/dump.p", "wb" ) )
+            pickle.dump( self.lines, open( "cedict_utils/data/dump.dat", "wb" ) )
 
     def _sanitize(self):
         from operator import methodcaller
